M_borrowTensorInto

Function M_borrowTensorInto 

pub unsafe extern "C" fn M_borrowTensorInto(
    tensors: *mut M_AsyncTensorMap,
    input: *mut c_void,
    tensorSpec: *const M_TensorSpec,
    status: *mut M_Status,
)
Adds a tensor to the tensor map.

You are responsible for the lifetime of the input tensor data. Its data gets “borrowed” into the Tensor Map.

@param tensors The tensor map, from M_newAsyncTensorMap(). @param input The input tensor data. @param tensorSpec The tensor spec, from M_newTensorSpec(). This gets copied as part of the operation of M_borrowTensorInto, so your original tensorSpec need not exist through the lifetime of the tensor map. @param status The status object for reporting errors.