pub unsafe extern "C" fn M_freeTensorNameArray(
names: *mut M_TensorNameArray,
)Expand description
Deallocates the memory for the array of tensor names. No-op if names is
NULL.
@param names The tensor names to deallocate.
pub unsafe extern "C" fn M_freeTensorNameArray(
names: *mut M_TensorNameArray,
)Deallocates the memory for the array of tensor names. No-op if names is
NULL.
@param names The tensor names to deallocate.