M_getName

Function M_getName 

pub unsafe extern "C" fn M_getName(
    spec: *mut M_TensorSpec,
) -> *const c_char
Gets the name of the tensor from the tensor spec.

@param spec The tensor spec.

@return A null-terminated string containing the name of the tensor if the spec is valid. Otherwise, NULL. The memory associated with the returned string is owned by spec.