M_getRank

Function M_getRank 

pub unsafe extern "C" fn M_getRank(spec: *const M_TensorSpec) -> i64
Gets the rank from the tensor spec.

@param spec The tensor spec.

@return The number of dimensions in the tensor spec if the spec is static and valid, kDynamicRankValue if dynamic. Otherwise, 0.