M_getTensorData

Function M_getTensorData 

pub unsafe extern "C" fn M_getTensorData(
    tensor: *const M_AsyncTensor,
) -> *const c_void
Gets a pointer to underlying data of the tensor.

@param tensor The tensor which must not be NULL.

@return A pointer to the underlying data of the tensor. This pointer is valid for the lifetime of the underlying tensor.