pub unsafe extern "C" fn M_getTensorNumElements(
tensor: *const M_AsyncTensor,
) -> usizeExpand description
Gets the number of elements for the tensor.
@param tensor The tensor which must not be NULL.
@return The number of elements for the given tensor.