pub unsafe extern "C" fn M_isDynamicRanked(
spec: *const M_TensorSpec,
) -> c_intExpand description
Returns if the given spec has a dynamic rank.
@param spec The tensor spec.
@return 1 if the rank is dynamic. 0 otherwise.
pub unsafe extern "C" fn M_isDynamicRanked(
spec: *const M_TensorSpec,
) -> c_intReturns if the given spec has a dynamic rank.
@param spec The tensor spec.
@return 1 if the rank is dynamic. 0 otherwise.