M_newAsyncTensorMap

Function M_newAsyncTensorMap 

pub unsafe extern "C" fn M_newAsyncTensorMap(
    context: *const M_RuntimeContext,
) -> *mut M_AsyncTensorMap
Creates a map of tensor names to async tensors.

@param context The runtime context.

@return A pointer to the tensor map. You are responsible for the memory associated with the pointer returned. The memory can be deallocated by calling M_freeAsyncTensorMap().