M_newCompileConfig

Function M_newCompileConfig 

pub unsafe extern "C" fn M_newCompileConfig() -> *mut M_CompileConfig
Creates an object you can use to configure model compilation.

You need M_CompileConfig as an argument for several functions, including M_setModelPath() and M_compileModel().

@returns A pointer to a new compilation configuration. You are responsible for the memory associated with the pointer returned. You can deallocate the memory by calling M_freeCompileConfig(). This compilation configuration can only be used for a single compilation call. Any subsequent compilations must be passed a new M_CompileConfig (created by calling M_newCompileConfig() again).