M_newRuntimeConfig

Function M_newRuntimeConfig 

pub unsafe extern "C" fn M_newRuntimeConfig() -> *mut M_RuntimeConfig
Creates a new runtime config.

This configures runtime details such as the number of threads and log level.

By default, the config object’s number of threads will be set to 0, which is internally used to refer to the number of physical processors in the first socket in the system. You can change this with M_setNumThreads().

You need this as an argument for M_newRuntimeContext().

@returns A pointer to the new runtime config. You are responsible for the memory associated with the pointer returned. You can deallocate the memory by calling M_freeRuntimeConfig().