M_newStatus

Function M_newStatus 

pub unsafe extern "C" fn M_newStatus() -> *mut M_Status
Creates a new status object.

This is required as an argument for several functions, such as M_newRuntimeContext() and M_compileModel(). They will update the status object and you can check for errors with M_isError() and get the status message with M_getError(). For example:

M_Status *status = M_newStatus();
M_RuntimeConfig *runtimeConfig = M_newRuntimeConfig();
M_RuntimeContext *context = M_newRuntimeContext(runtimeConfig, status);
if (M_isError(status)) {
  logError(M_getError(status));
  return EXIT_FAILURE;
}

@returns A pointer to the new status object. You are responsible for the memory associated with the pointer returned. You can deallocate the memory by calling M_freeStatus().