M_replayModelSync

Function M_replayModelSync 

pub unsafe extern "C" fn M_replayModelSync(
    context: *const M_RuntimeContext,
    initializedModel: *mut M_AsyncModel,
    graphKeys: *const u64,
    numGraphKeys: usize,
    inputs: *const *mut M_AsyncTensor,
    numInputs: usize,
    status: *mut M_Status,
)
Replays a previously captured device graph.

The inputs must use the same buffers (same addresses, shapes, dtypes, and devices) as the inputs used during M_captureModelSync(). Results are written to the output tensors returned by the original capture call.

@param context The runtime context, from M_newRuntimeContext(). @param initializedModel The model containing the captured graph, from M_initModel(). @param graphKeys Array of uint64_t graph keys matching those used in M_captureModelSync(). @param numGraphKeys Number of graph keys. @param inputs Array of input tensors matching the capture-time signature. @param numInputs Number of input tensors. @param status The status used to report errors in the case of failures.