M_runtimeConfigAddDevice

Function M_runtimeConfigAddDevice 

pub unsafe extern "C" fn M_runtimeConfigAddDevice(
    config: *mut M_RuntimeConfig,
    device: *mut M_Device,
)
Adds a device to be accessible from the runtime.

@param config The runtime config. @param device The device to add to the runtime config.