M_setModelPath

Function M_setModelPath 

pub unsafe extern "C" fn M_setModelPath(
    compileConfig: *mut M_CompileConfig,
    path: *const c_char,
)
Sets the path to a model.

You must call this before you call M_compileModel(). Otherwise, M_compileModel() returns an error in status.

@param compileConfig The compilation configuration for your model, from M_newCompileConfig(). @param path The path to your model. The model does not need to exist on the filesystem at this point. This follows the same semantics and expectations as std::filesystem::path.