pub unsafe extern "C" fn M_getName(
spec: *mut M_TensorSpec,
) -> *const c_charExpand description
Gets the name of the tensor from the tensor spec.
@param spec The tensor spec.
@return A null-terminated string containing the name of the tensor if the
spec is valid. Otherwise, NULL.
The memory associated with the returned string is owned by spec.