M_getTensorDevice

Function M_getTensorDevice 

pub unsafe extern "C" fn M_getTensorDevice(
    tensor: *const M_AsyncTensor,
) -> *mut M_Device
Gets the device on which a tensor resides.

@param tensor The tensor.

@return The device on which the tensor resides, or NULL if the tensor is invalid. The caller owns the returned device and must free it with M_freeDevice().