M_getTensorNumElements

Function M_getTensorNumElements 

pub unsafe extern "C" fn M_getTensorNumElements(
    tensor: *const M_AsyncTensor,
) -> usize
Gets the number of elements for the tensor.

@param tensor The tensor which must not be NULL.

@return The number of elements for the given tensor.