pub unsafe extern "C" fn M_setDebugPrintOptions(
context: *mut M_RuntimeContext,
style: M_ResultOutputStyle,
precision: c_uint,
directory: *const c_char,
)Expand description
Set the options for debugging printing of tensors when executing a model.
@param context The runtime context. @param style The way the data will be printed. @param precision The floating point print out precision. @param directory The directory to store binary output.