pub unsafe extern "C" fn M_waitForCompilation(
compiledModel: *mut M_AsyncCompiledModel,
status: *mut M_Status,
)Expand description
Blocks execution until the model is compiled.
This waits for the async compiled model to be complete after calling
M_compileModel(). When this function returns, the model is resolved to
either a compiled model or an error.
@param compiledModel The model received from M_compileModel().
@param status The status used to report errors in the case of failures.