pub unsafe extern "C" fn M_waitForModel(
model: *mut M_AsyncModel,
status: *mut M_Status,
)Expand description
Blocks execution until the model is initialized.
This waits for the model setup to finish in M_initModel().
@param model The model. @param status The status used to report errors in the case of failures.